import Qt 4.7

Item {
    id: box
    width: 350;
    height: 64

    Image {
        id: zoomInImage
        height: parent.height
        source: "zoom-in.png"
        fillMode: Image.PreserveAspectFit
        anchors.left: parent.left
        smooth: true

        NumberAnimation {
            id: zoomInAnimation
            target: zoomInImage; property: "scale"; from: 0.75; to: 1.0; duration: 100
        }

        MouseArea {
            anchors.fill: parent
            acceptedButtons: Qt.LeftButton

            onClicked: {
                zoomInAnimation.running = true;
                var zoomLevel = MapWidget.zoomLevel;
                MapWidget.setZoomLevel(++zoomLevel)
                console.log("QML MapWidget: zoom in")
            }
        }
    }

    Flipable {
        id: container
        property bool flipped: !GeoEngine.isOnline
        property int angle: 180

        anchors.horizontalCenter: parent.horizontalCenter
        width: front.width; height: front.height

        back: Text {
            id: offlineMode
            text: "offline"
            color: "gray"
            opacity: 0.8
            font.pointSize: box.height/2
            font.bold: true
            style: Text.Outline;
            styleColor: "black"
            smooth: true
        }

        front: Text {
            id: onlineMode
            text: "online"
            color: "limegreen"
            opacity: 0.8
            font.pointSize: box.height/2
            font.bold: true
            style: Text.Outline;
            styleColor: "black"
            smooth: true
        }


        state: "back"

        MouseArea {
            anchors.fill: parent;
            onClicked: {
                console.log("QML MapWidget: network mode clicked")

                GeoEngine.setOnline(!GeoEngine.isOnline);
            }
        }

        Connections {
            target: GeoEngine
            onOnlineEnabled: {
                console.log("QML MapWidget: onOnlineEnabled()")
                container.flipped = !GeoEngine.isOnline;
            }
        }

        transform: Rotation {
            id: rotation; origin.x: container.width / 2; origin.y: container.height / 2
            axis.x: 0; axis.y: 1; axis.z: 0
        }

        states: State {
            name: "back"; when: container.flipped
            PropertyChanges { target: rotation; angle: container.angle }
        }

        transitions: Transition {
            ParallelAnimation {
                NumberAnimation { target: rotation; properties: "angle"; duration: 600 }
                SequentialAnimation {
                    NumberAnimation { target: container; property: "scale"; to: 0.75; duration: 300 }
                    NumberAnimation { target: container; property: "scale"; to: 1.0; duration: 300 }
                }
            }
        }
    }

    Image {
        id: zoomOutImage
        height: parent.height
        source: "zoom-out.png"
        fillMode: Image.PreserveAspectFit
        anchors.right: parent.right
        smooth: true

        NumberAnimation {
            id: zoomOutAnimation
            target: zoomOutImage; property: "scale"; from: 0.75; to: 1.0; duration: 100
        }

        MouseArea {
            anchors.fill: parent
            acceptedButtons: Qt.LeftButton

            onClicked: {
                zoomOutAnimation.running = true
                var zoomLevel = MapWidget.zoomLevel;
                MapWidget.setZoomLevel(--zoomLevel)
                console.log("QML MapWidget: zoom out")
            }
        }
    }
}
